#[non_exhaustive]pub enum PossibleOffset {
Single(Offset),
Ambiguous {
before: Offset,
after: Offset,
transition: i64,
},
None {
before: Offset,
after: Offset,
transition: i64,
},
}Expand description
Possible offsets for a local datetime
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Single(Offset)
There is a single possible offset
Ambiguous
There are multiple possible offsets, because we are inside a backward transition
Note: Temporal requires these to be in ascending order of offset, Temporal consumers should sort them
Fields
None
There is no possible offset, because we are at a forward transition